package Lagrange::BesselF0;

use parent 'Lagrange::BesselF';

### first degree
sub new {
	my ($class, $name) = @_;
        my $self = $class->SUPER::new;

}

sub funcall {

	my ($self, $x) = @_;



}

1;
